%
%   XEFFECT_011413_POST.M    Post Analysis of the Xenon Reactivity 
%                             Experiment performed Jan. 14, 2013
%
%   An experiment was performed in the UMLRR on Jan. 14, 2013.  The goal of this 
%   specific test was to validate or modify, as needed, an analytical xenon 
%   reactivity model that had been previously developed for the UMLRR.  The reactor
%   test was pretty simple: that is, the reactor was run at steady state at near full 
%   power with approximately constant temperature for about 4.5 hours.  During 
%   the run, the regulating blade was put in auto mode, and it was observed to
%   continually move out of the core over the 4+ hour period, while maintaining
%   the reactor at the just critical state.  The positive reactivity associated with
%   the reg rod moving out was needed to compensate for the negative reactivity 
%   associated with the buildup of xenon in the system.  This should allow an
%   indirect measure of the xenon reactivity.
%
%   This file does the post analysis calculations for this experiment.  The reactor
%   data for the run have been processed and stored in file xeffect_011413.dat.  
%   This dataset contains information for several different reactor measurements.  
%   The measurements were taken at 1 second intervals, but this info has been 
%   averaged over 30 sec periods.  
%
%   The sequence of steps in the analysis is:
%     1. Read data file and plot some of the data to summarize reactor operations
%        during the run.  The most important parameter, of course, is the reg rod
%        position versus time and the temperature vs time.  This step just validates 
%        that we have the correct data (visualization was already done with the
%        umlrr_data GUI).
%     2. Use the RR blade worth curve and measured z(t) to generate rho(t).
%     3. Although the temperature change was small we will try to correct for this
%        with a fixed reactivity coeff using a rough average core temperature.
%        Hopefully this correction will be small.  The result, after removing the 
%        temperature component from the total compensated reactivity, will be the 
%        "measured" Xe reactivity vs. time...
%     4. Use the analytical xenon model to compute calculated reactivtiy vs. time
%        and compare the two profiles. 
%     3. If needed, adjust the model parameters (i.e. flux magnitude) to give a 
%        better fit to the measured data.
%  
%   Note #1:
%   This procedure was done a little differently back in 2004 (ie. the first time
%   I tried this).  In the current version, I compare the calculated and measured 
%   xenon reactivtities (instead of the RegBlade position).  The current approach 
%   is easier and definitely more straightforward...
%   Note #2:
%   The optimum correction factor from the 2004 experiment were as follows:
%       Bopt = 0.9338 using 1999 data
%       Bopt = 0.8785 using 2010 data  (clearly not as good -- but nearly exact
%              with correction factor)
%   The goal here is to see if the correction factor for the best fit has changed...
%
%   File prepared by J. R. White, UMass-Lowell (March 2, 2013)
%   Code modified to use recent function files and to clean up some edit -- however,
%   no fundamental changes were made and there was no change in the results.  
%   Basically, just did some house cleaning...              (JRWhite, March 2, 2014)
%   Update:  Added capability to selected the temperature coeff to use (measured or
%   calculated).  This makes a fairly large difference.  But I am still not sure
%   which one is correct  --  if any.                       (JRWhite, Nov. 22, 2015)
%

      clear all, close all, nfig = 0;
%
%   read experimental data
      fname = 'xeffect_011413.dat';
      [data,tags,exptdate,starttime] = read_datfile(fname); 
%
%   plot some data to view reactor operation during the run
      teh = data(:,1)/3600;      % time vector for expt (hous)
      tunits = 'hours';          % time units for plots
      titl = 'Xeffect\_Post';    % for use in title of plots
      nfig = plot_PTB(teh,data,tags,exptdate,nfig,titl,tunits);  
%   also plot the flow indicators  (secondary flow rate was used to control the temp)   
      Ncm = 6;  scm = ['r- ';'b: ';'g-.';'m--';'c- ';'k: ']; 
      nfig = nfig+1;  figure(nfig);
      xtags = ['PriFlow ';'SecFlow '];  
      itag = gettagloc(xtags,tags); ntag = length(itag);  % tags of interest 
      st = char(zeros(ntag,8));                % storage for labels in legend command
      jj = 0;                                  % counters for marker type       
      for j = 1:ntag
        it = itag(j);   jj = jj+1;  if jj > 6, jj = 1; end
        plot(teh,data(:,it),scm(jj,:),'LineWidth',2); hold on 
        st(j,:) = tags(it,:);
      end 
      grid on, hold off                          
      title(['Xeffect\_Post: Flow Rate Indicators for Experiment on ',exptdate]); 
      xlabel('Elapsed Time (hours)'),ylabel('Volume Flow Rate (gpm)')
      legend(st,'Location','SouthEast')

%%
%   get compensated reactivity, temperature correction, and total Xe effect vs time 
      itag = gettagloc('RRodPos ',tags);  z = data(:,itag); % reg blade loc vs time 
      RBdate = 'Feb. 2013';  boi = 5;  yr = 2013;
      mtotrho = bworth(z,boi,yr)-bworth(z(1),boi,yr); % meas tot compensated rho %Dk/k
      itag = gettagloc('CoreTout',tags);  Tout = data(:,itag); % Tout (oF) 
      Tcore = Tout - 2.0;        % core ave temp (oF)
      TcoreC = (Tcore-32)/1.8;   % core ave temp (oC)
      DT = TcoreC - TcoreC(1);   % temp difference from reference
      ialf = menu('Select Reactivity Coeff. to use', ...
                  'Use MEASURED constant value from Expt. on 1/22/13', ...
                  'Use the MEASURED temperature dependent value from Expt. on 1/22/13', ...
                  'Use the CALCULATED temperature dependent value from work in Summer 2015');
      switch ialf 
        case 1   % measured temp coeff (%Dk/k-C) (expt from 012213)
          alf = -5.87e-3;   
        case 2   % approx total temp coeff (%Dk/k-C) (expt from 012213)
          alf = -2.878e-4*TcoreC + 1.232e-3;
        case 3   % approx total temp coeff (%Dk/k-C) (from summer 2015)
          alf = -2.119e-4*TcoreC - 9.240e-3; 
      end
      rhoTemp = abs(alf.*DT);    % total temperature reactivity (%Dk/k)
      mrhoX = mtotrho - rhoTemp; % measured Xe reactivity (%Dk/k)
%
%   Note: Usually I take the average of the inlet and outlet temps for Tcore.  
%         However the inlet temp seems to be in error, so here I will simply take the
%         outlet temp - 2 F (since the core delta T is about 4 F).  This should be
%         reasonable.  Also, a reasonable total (fuel + coolant) temp coeff of 
%         reactivity is between -2.5e-5 and -4.0e-5 & Dk/k per F.  I will use 
%         somewhere in the middle (again, the overall effect should be small).
%
      nfig   = nfig+1;   figure(nfig);
      plot(teh,mtotrho,'r-',teh,rhoTemp,'g--',teh,mrhoX,'b-.','LineWidth',2),grid
      title(['Xeffect\_Post: Measured Xenon Reactivtiy for Expt on ',exptdate])
      xlabel('Elapsed Time (hours)'),ylabel('Reactivtiy (% \Deltak/k)')
      legend('Measured \rho_{total}','Predicted \rho_{Temp}','Measured \rho_{Xe}', ...
             'Location','NorthWest')
%
%   compute the predicted xenon reactivity based on analytical model (no correction) 
      cfac = 1.0;                       % no correction factor initially
      rp = 0.930;                       % ave relative power (some uncertainty here)
      t = data(:,1);                    % time vector for xenon reactivity calc (sec)
      Io = 0;   Xo = 0;                 % zero ICs
      [rhoX] = xenon(t,rp,cfac,Io,Xo);  % call function to compute rhoX(t) (Dk/k)
      crhoX = rhoX*100;                 % calculated Xe reactivity (% Dk/k)
%
%   plot the predicted and measured Xe reactivtiy -- this was the real goal here
      nfig   = nfig+1;   figure(nfig);
      plot(teh,crhoX,'r-',teh,mrhoX,'b--','LineWidth',2),grid
      title(['Xeffect\_Post: Calculated and Measured \rho_{Xe} for Expt on ',exptdate])
      xlabel('Elapsed Time (hours)'),ylabel('Reactivtiy (% \Deltak/k)')
      legend(['Predicted \rho_{Xe} (cf = ',num2str(cfac,'%5.3f'),')'], ...
              'Measured \rho_{Xe}','Location','NorthWest')
%
%   The above comparison is off and we expected this from previous work, since we
%   know that cfac should be about 0.88 (for 2010 xsec data).  Let's use Matlab's 
%   nonlinear regression analysis to try to get a better fit and to see if cfac has 
%   changed much....
%
%   Note: If you do not have the nlinfit function in your version of Matlab 
%         (requires the Statistical Analysis toolbox), simply comment out the next 
%         few lines, and physically set cfnew = cfac = 0.882  (for 2010 data)
%         for use in the call to xenon.
      Fcft = @(cf,t) xenon(t,rp,cf,Io,Xo);
      cfnew = nlinfit(t,mrhoX/100,Fcft,cfac);
      [rhoX] = xenon(t,rp,cfnew,Io,Xo);     % call function to compute rhoX(t) (Dk/k)
      crhoX = rhoX*100;                     % calculated Xe reactivity (% Dk/k)
%
%   plot the predicted and measured Xe reactivtiy with use of the new cfac
      nfig   = nfig+1;   figure(nfig);
      plot(teh,crhoX,'r-',teh,mrhoX,'b--','LineWidth',2),grid
      title(['Xeffect\_Post: Calculated and Measured \rho_{Xe} for Expt on ',exptdate])
      xlabel('Elapsed Time (hours)'),ylabel('Reactivtiy (% \Deltak/k)')
      legend(['Predicted \rho_{Xe} (cf = ',num2str(cfnew,'%5.3f'),')'], ...
              'Measured \rho_{Xe}','Location','NorthWest')
%
%   end of program