%
%   XENON.M    Function to solve the I-Xe equations using data for the UMLRR 
%             for a time interval where the power and flux levels are constant
%
%   The theory and specifc equations implemented here are documented in the Lecture
%   Notes: Xenon Poisoning in Thermal Reactors.  The only difference is the addition
%   of a flux correction factor, cfac (see below).
%
%   This was updated in Jan. 2013 to include data for two physcis models.  The 2010
%   data are default, but the user can change the value of idata (see below) to select
%   the 1999 data if desired.  
%
%   Note also that the correction factor (cfac) was computed using experimental data 
%   from Nov. 2004 to be as follows: 
%    for 1999 xs data:  cfac = 0.934    and    for 2010 xs data:  cfac = 0.879
%   Note that cfac is an input to this routine, so the user must supply the correct 
%   value...
%
%   Inputs:  
%     t = time vector (seconds)
%     rp = relative power (fraction of full power)
%     cfac = flux correction factor  (see note above)
%     Io = initial I-135 concentration for interval (atoms/cm^3)
%     Xo = initial Xe-135 concentration for interval (atoms/cm^3)
%
%   Outputs:
%     rho = Xe-135 reactivity vs time for interval (Dk/k)
%     I = I-135 concentration vs time for interval (atoms/cm^3)
%     X = Xe-135 concentration vs time for interval (atoms/cm^3)
%
%   File prepared by J. R. White, UMass-Lowell (Jan. 2013)
%

      function [rho,I,X] = xenon(t,rp,cfac,Io,Xo)
%
%   define I-Xe decay parameters (from Lamarsh)
      Thi = 6.7;                % half life for I-135 (hr)
      dci = log(2)/Thi/3600;    % decay constant for I-135 (1/sec)
      Thx = 9.2;                % half life for Xe-135 (hr)
      dcx = log(2)/Thx/3600;    % decay constant for Xe-135 (1/sec)
      yi = 0.0639;              % yield for U235 for I-135 (atoms/fission)
      yx = 0.00237;             % yield for U235 for Xe-135 (atoms/fission)
%
%   set xenon micro xsec (from Lamarsh)
      T = 293;  To = 293;       % absolute temperatures (K)
      ga = 1.158;               % non 1/v factor for Xe-135  (at T = 20 C = 293 K))
      sigaxo = 2.65e+6;         % 2200 m/s abs xsec for Xe-135  (barns)
      cm2pb = 1e-24;            % conversion factor (cm^2/barn)
      sigax = (sqrt(pi)/2)*ga*sigaxo*cm2pb*sqrt(To/T);   % thermal ave abs xs (cm^2)
%
%   data for UMLRR simulations (see results from umlrr_6factors.m)
      Pfull = 1e+6;                               % UMLRR full power level (W)
      kappa = 200*1.602e-13;                      % energy per fission (J = W-s)
      assydim = 7.7724;                           % assy square dimension (cm)
      fuelht = 59.69;                             % fuel heigth (cm)
      Vcore = 4*5*assydim^2*fuelht;               % core vol for 4x5 array (cm^3)
%       idata = menu('Select 2-g data set for the simulations:', ...
%                    ' Data generated in 1999 using SCALE 4.2  ', ...
%                    ' Data generated in 2010 using SCALE 6.0  ');
      idata = 2;   % default to the 2010 data
      if idata == 1     % ***  1999 data  ***
        nu = 2.434; p = 0.9272; epp = 1.0541;     % nu & factors of 4-factor formula
        PF = 0.6737; PT = 0.9690;                 % non-leakage probabilities
        sigf1 = 1.017e-3; sigf2 = 5.046e-2;       % macro fission xsecs (1/cm)
        ratio = 2.6368;                           % fast to thermal flux ratio
      else              % ***  2010 data  ***
        nu = 2.434; p = 0.8794; epp = 1.0674;     % nu & factors of 4-factor formula
        PF = 0.6652; PT = 0.9691;                 % non-leakage probabilities
        sigf1 = 1.214e-3; sigf2 = 5.036e-2;       % macro fission xsecs (1/cm)
        ratio = 2.7528;                           % fast to thermal flux ratio
      end
      denom = nu*p*epp*PF*PT;                     % denominator of reactivity eqn.
      sigfeff = sigf1*ratio+sigf2;                % effective fiss xs (1/cm)
      flxfull = Pfull/(kappa*sigfeff*Vcore);      % 1 MW ave thm flux (neuts/cm^2-s)      
%
%   now compute I(t), X(t), and rho(t)
      flx = cfac*rp*flxfull;    w = sigax*flx + dcx;   II = yi*sigfeff*flx/dci;   
      XX1 = (yi+yx)*sigfeff*flx/w;  XX2 = (yi*sigfeff*flx - Io*dci)/(w - dci);
      I = Io*exp(-dci*t) + II*(1 - exp(-dci*t));
      X = Xo*exp(-w*t) + XX1*(1 - exp(-w*t)) + XX2*(exp(-w*t) - exp(-dci*t));
      rho = X*sigax/sigf2/denom;
%
%   end of function
